from gzip import GzipFile
from io import TextIOWrapper
from pathlib import Path
from random import Random

from tqdm import tqdm

REVIEW_SAMPLE_SIZE = 1000

DATA_PATH = Path(
    "/mnt/ceph/storage/data-in-progress/data-research/"
    "web-search/web-archive-query-log/focused/"
)

SAMPLE_CORPUS_PATH = DATA_PATH / "sample-corpus"
SAMPLE_QUERIES_PATH = SAMPLE_CORPUS_PATH / "queries"
SAMPLE_DOCUMENTS_PATH = SAMPLE_CORPUS_PATH / "documents"

REVIEW_SAMPLE_CORPUS_PATH = DATA_PATH / "review-corpus-unfiltered"
REVIEW_SAMPLE_CORPUS_PATH.mkdir(exist_ok=True)
REVIEW_SAMPLE_QUERIES_PATH = REVIEW_SAMPLE_CORPUS_PATH / "queries.jsonl"
REVIEW_SAMPLE_DOCUMENTS_PATH = REVIEW_SAMPLE_CORPUS_PATH / "documents.jsonl"


def main():
    lines = []
    for path in tqdm(list(SAMPLE_QUERIES_PATH.glob("part*.gz"))):
        # noinspection PyTypeChecker
        with GzipFile(path, "rb") as gf, TextIOWrapper(gf) as f:
            for line in f:
                if "\"archived_query_url_location\": {" not in line:
                    continue
                if "\"archived_raw_serp_location\": {" not in line:
                    continue
                # if "\"archived_parsed_serp_location\": {" not in line:
                #     continue
                lines.append(line)

    random = Random(0)  # nosec: B311
    lines = random.sample(lines, REVIEW_SAMPLE_SIZE)

    with REVIEW_SAMPLE_QUERIES_PATH.open("wt") as o:
        for line in lines:
            o.write(line)


if __name__ == '__main__':
    main()



from uuid import uuid4

from click import echo, prompt
from elasticsearch_dsl import Search
from elasticsearch_dsl.query import Terms
from elasticsearch_dsl.response import Response

from archive_query_log.config import Config
from archive_query_log.orm import Provider
from archive_query_log.utils.time import utc_now


def add_provider(
    config: Config,
    name: str | None,
    description: str | None,
    notes: str | None,
    exclusion_reason: str | None,
    domains: set[str],
    url_path_prefixes: set[str],
    priority: float | None,
    no_merge: bool = False,
    auto_merge: bool = False,
) -> None:
    if priority is not None and priority <= 0:
        raise ValueError("Priority must be strictly positive.")
    config.es.client.indices.refresh(index=config.es.index_providers)
    last_modified = utc_now()
    should_build_sources = True
    existing_provider_search: Search = Provider.search(
        using=config.es.client, index=config.es.index_providers
    ).query(Terms(domains=list(domains)))
    existing_provider_response: Response = existing_provider_search.execute()
    if existing_provider_response.hits.total.value > 0:
        if no_merge:
            return
        existing_provider: Provider = existing_provider_response[0]
        existing_domains = set(existing_provider.domains)
        existing_url_path_prefixes = set(existing_provider.url_path_prefixes)
        provider_id = existing_provider.id
        if auto_merge:
            should_merge = True
        else:
            intersecting_domains = existing_domains & domains
            first_intersecting_domains = sorted(intersecting_domains)[:5]
            intersecting_domains_text = ", ".join(first_intersecting_domains)
            num_more_intersecting_domains = len(intersecting_domains) - len(
                first_intersecting_domains
            )
            if num_more_intersecting_domains > 0:
                intersecting_domains_text += f" (+{num_more_intersecting_domains} more)"
            echo(
                f"Provider {provider_id} already exists with "
                f"conflicting domains: {intersecting_domains_text}"
            )
            add_to_existing = prompt(
                "Merge with existing provider? " "[y/N]",
                type=str,
                default="n",
                show_default=False,
            )
            should_merge = add_to_existing.lower() == "y"
        if not should_merge:
            return

        if name is None:
            name = existing_provider.name
        if description is None:
            description = existing_provider.description
        if notes is None:
            notes = existing_provider.notes
        if exclusion_reason is None:
            exclusion_reason = existing_provider.exclusion_reason
        if priority is None:
            priority = existing_provider.priority

        if (
            domains | existing_domains == existing_domains
            and url_path_prefixes | existing_url_path_prefixes
            == existing_url_path_prefixes
        ):
            last_modified = existing_provider.last_modified
            should_build_sources = existing_provider.should_build_sources

        domains = domains | existing_domains
        url_path_prefixes = url_path_prefixes | existing_url_path_prefixes

        if not auto_merge:
            echo(f"Update provider {provider_id}.")
    else:
        provider_id = str(uuid4())
        if not no_merge and not auto_merge:
            echo(f"Add new provider {provider_id}.")

    provider = Provider(
        id=provider_id,
        last_modified=last_modified,
        name=name,
        description=description,
        notes=notes,
        exclusion_reason=exclusion_reason,
        domains=list(domains),
        url_path_prefixes=list(url_path_prefixes),
        priority=priority,
        should_build_sources=should_build_sources,
    )
    provider.save(using=config.es.client, index=config.es.index_providers)



import pandas as pd


def combine_alexa_manual(manual_csv: str, alexa_csv: str):
    """
    Function to combine the CSV created by search_forms.py
    with a manual collection of search engines
    :param manual_csv:  Path to the CSV containing a manual collection
        of search engines
    :param alexa_csv:   Path to the CSV containing the automatically
        created list of services
    :return:            A pd.DataFrame that combined both source CSVs
    """
    m_df = pd.read_csv(manual_csv)
    a_df = pd.read_csv(alexa_csv)
    a_df.drop("Unnamed: 0", axis=1, inplace=True)

    # Get identically formatted service names for both
    m_df["Service"] = m_df["Service"].str.lower()
    m_df.rename({"Service": "service"}, axis=1, inplace=True)
    a_df["service"] = a_df["service"].str.split(".").str[0]

    # Create new alexa df with unique service names and store
    # the duplicates to be added later
    a_df_unique = a_df.drop_duplicates(subset="service")
    a_df_merged = a_df.merge(a_df_unique, on=["rank", "rank"], how="left",
                             indicator=True)
    a_df_dup = a_df_merged[a_df_merged["_merge"] == "left_only"]
    a_df_dup = a_df_dup.loc[:, ~a_df_dup.columns.str.contains("_y")]
    a_df_dup.columns = a_df_dup.columns.str.rstrip("_x")
    a_df_dup.drop("_merge", axis=1, inplace=True)

    # Create merged df by performing an outer join on both df
    merged_df = pd.concat([a_df_unique.set_index("service"),
                           m_df.set_index("service")], axis=1,
                          join="outer").reset_index()
    merged_df = pd.concat([merged_df, a_df_dup], ignore_index=True)
    cols_reordered = ["rank", "service", "tld", "Search Category", "input",
                      "search_form", "search_div",
                      'input_snippets', 'form_snippets', 'div_snippets']
    merged_df = merged_df[cols_reordered]

    merged_df["rank"].fillna(99999, inplace=True)
    merged_df.sort_values("rank", inplace=True)
    return merged_df



from click import group

from archive_query_log.cli.util import pass_config
from archive_query_log.config import Config


@group()
def results():
    pass


@results.group()
def download():
    pass


@download.command(help="Download archived documents of captures as WARC.")
@pass_config
def warc(config: Config) -> None:
    raise NotImplementedError("This command is not yet implemented.")
    # from archive_query_log.downloaders.warc import download_results_warc
    # download_results_warc(config)



from pathlib import Path
from typing import Iterable
from webbrowser import open_new_tab

from approvaltests import verify_as_json, ApprovalException
from approvaltests.core.options import Options
from approvaltests.namer.cli_namer import CliNamer
from slugify import slugify
from tqdm.auto import tqdm

from archive_query_log.legacy import PROJECT_DIRECTORY_PATH
from archive_query_log.legacy.config import SERVICES
from archive_query_log.legacy.download.iterable import ArchivedRawSerps
from archive_query_log.legacy.model import ArchivedParsedSerp, \
    ArchivedRawSerp, ResultsParser, InterpretedQueryParser, Service
from archive_query_log.legacy.results.parse import ArchivedParsedSerpParser

_expected_dir = PROJECT_DIRECTORY_PATH / \
                "data/manual-annotations/" \
                "archived-raw-serps/expected/"
_warc_dir = PROJECT_DIRECTORY_PATH / \
            "data/manual-annotations/" \
            "archived-raw-serps/warcs/"


def verify_serp_parsing(
        wayback_raw_url: str,
        service_name: str | None = None,
) -> None:
    services: Iterable[Service]
    if service_name is None:
        services = SERVICES.values()
    else:
        services = [SERVICES[service_name]]

    result_parsers: list[ResultsParser] = []
    interpreted_query_parsers: list[InterpretedQueryParser] = []
    for service in services:
        result_parsers += service.results_parsers
        interpreted_query_parsers += service.interpreted_query_parsers
    parser = ArchivedParsedSerpParser(
        result_parsers,
        interpreted_query_parsers,
    )

    archived_raw_serp = _find_archived_raw_serp(wayback_raw_url)
    archived_parsed_serp = parser.parse_single(archived_raw_serp)

    try:
        _verify_archived_parsed_serp_results(
            archived_raw_serp,
            archived_parsed_serp,
            service_name,
        )
    except ApprovalException as e:
        open_new_tab(archived_raw_serp.raw_archive_url)
        raise e


def _find_archived_raw_serp(wayback_raw_url: str) -> ArchivedRawSerp:
    num_files = sum(1 for _ in _warc_dir.glob("*.warc.gz"))
    print(
        f"Searching for record with URL {wayback_raw_url} in {_warc_dir} "
        f"({num_files} files)"
    )
    records: Iterable[ArchivedRawSerp] = ArchivedRawSerps(path=Path(_warc_dir))
    # noinspection PyTypeChecker
    records = tqdm(
        records,
        desc="Find record for URL",
        unit="record",
    )
    record: ArchivedRawSerp
    for record in records:
        if record.raw_archive_url == wayback_raw_url:
            return record

    raise ValueError(
        f'Could not find record with URL {wayback_raw_url} in {_warc_dir}')


_schema = ArchivedParsedSerp.schema()


def _verify_archived_parsed_serp_results(
        archived_raw_serp: ArchivedRawSerp,
        archived_parsed_serp: ArchivedParsedSerp | None,
        service: str | None = None,
) -> None:
    if archived_parsed_serp is not None:
        actual = _schema.dump(archived_parsed_serp)
    else:
        actual = None
    query = archived_raw_serp.query
    query = slugify(query)
    query = query[:100]
    name = f"{query}-{archived_raw_serp.timestamp}"
    if service is not None:
        name = f"{service}-{name}"
    name = slugify(name)
    verify_as_json(
        actual,
        options=Options().with_namer(
            CliNamer(f"{_expected_dir}/{name}")
        )
    )



from typing import Any, Type, Iterable

from click import group, Context, Parameter, echo, option, pass_context
from dotenv import find_dotenv, load_dotenv
from elasticsearch_dsl import Document
from tqdm.auto import tqdm

from archive_query_log import __version__ as app_version
from archive_query_log.cli.archives import archives
from archive_query_log.cli.captures import captures
from archive_query_log.cli.monitoring import monitoring
from archive_query_log.cli.parsers import parsers
from archive_query_log.cli.providers import providers
from archive_query_log.cli.results import results
from archive_query_log.cli.serps import serps
from archive_query_log.cli.sources import sources
from archive_query_log.cli.util import pass_config
from archive_query_log.config import Config
from archive_query_log.orm import (
    Archive,
    Provider,
    Source,
    Capture,
    Serp,
    Result,
    UrlQueryParser,
    UrlPageParser,
    UrlOffsetParser,
    WarcQueryParser,
    WarcSnippetsParser,
    WarcMainContentParser,
    WarcDirectAnswersParser,
)


def echo_version(
    context: Context,
    _parameter: Parameter,
    value: Any,
) -> None:
    if not value or context.resilient_parsing:
        return
    echo(app_version)
    context.exit()


@group()
@option(
    "-V",
    "--version",
    is_flag=True,
    callback=echo_version,
    expose_value=False,
    is_eager=True,
)
@pass_context
def cli(context: Context) -> None:
    if find_dotenv():
        load_dotenv()
    config: Config = Config()
    context.obj = config


@cli.command()
@pass_config
def init(config: Config) -> None:
    indices_list: list[tuple[Type[Document], str]] = [
        (Archive, config.es.index_archives),
        (Provider, config.es.index_providers),
        (Source, config.es.index_sources),
        (Capture, config.es.index_captures),
        (Serp, config.es.index_serps),
        (Result, config.es.index_results),
        (UrlQueryParser, config.es.index_url_query_parsers),
        (UrlPageParser, config.es.index_url_page_parsers),
        (UrlOffsetParser, config.es.index_url_offset_parsers),
        (WarcQueryParser, config.es.index_warc_query_parsers),
        (WarcSnippetsParser, config.es.index_warc_snippets_parsers),
        (WarcMainContentParser, config.es.index_warc_main_content_parsers),
        (WarcDirectAnswersParser, config.es.index_warc_direct_answers_parsers),
    ]
    # noinspection PyTypeChecker
    indices: Iterable[tuple[Type[Document], str]] = tqdm(
        indices_list,
        desc="Initialize indices",
        unit="index",
    )
    for document_type, index in indices:
        document_type.init(using=config.es.client, index=index)


cli.add_command(archives)
cli.add_command(providers)
cli.add_command(parsers)
cli.add_command(sources)
cli.add_command(captures)
cli.add_command(serps)
cli.add_command(results)
cli.add_command(monitoring)



# flake8: noqa
# This file is auto-generated by generate_tests.py.
from archive_query_log.legacy.results.test.test_utils import verify_serp_parsing


def test_parse_query_facebook_vanilla_1481832838():
    verify_serp_parsing(
        "https://web.archive.org/web/20161215201358id_/https://www.facebook.com/search/photos/?q=%23vanilla&ref=top_filter",
        "facebook",
    )


def test_parse_query_facebook_virpi_soikkeli_1623257178():
    verify_serp_parsing(
        "https://web.archive.org/web/20210609164618id_/http://www.facebook.com/search/?q=virpi+soikkeli&o=2048&init=ffs",
        "facebook",
    )


def test_parse_query_facebook_deanna_sanchez_1629215596():
    verify_serp_parsing(
        "https://web.archive.org/web/20210817155316id_/https://www.facebook.com/search/web/direct_search.php?q=deanna+sanchez&dpr=1&ajaxpipe=1&ajaxpipe_token=AXivh35bR9s2xXXV&quickling%5Bversion%5D=3128950%3B0%3B&__user=100004323191030&__a=1&__dyn=5V4cjEzUGByC5A9UrEwlg94qbxqbAKGiyEyfirYw8ovyui9zob4q2i5UK3u2CEaUZ1ebkwy6UnGieKcVrDG4XzEa8iGt0gKum4UpKqqbAWCDxi5UWfz8gAxu1iyECQum2m4oqyU9omUmC-Wx2vgqx-Eth8gUKElCUmyE8XDh45EgAwzCwYyrK4rGUohES-9yaBy8CEO784afxK9yUvy8lUGaHCG2C&__af=j0&__req=jsonp_4&__be=0&__pc=PHASED%3ADEFAULT&__rev=3128950&__spin_r=3128950&__spin_b=trunk&__spin_t=1498867474&__adt=4",
        "facebook",
    )


def test_parse_query_facebook_mr_robot_1469187052():
    verify_serp_parsing(
        "https://web.archive.org/web/20160722113052id_/https://www.facebook.com/search/top/?q=mr%20robot",
        "facebook",
    )


def test_parse_query_facebook_https_peelarchivesblog_com_about_peel_1599241783():
    verify_serp_parsing(
        "https://web.archive.org/web/20200904174943id_/https://www.facebook.com/search/top?q=https%3A%2F%2Fpeelarchivesblog.com%2Fabout-peel%2F",
        "facebook",
    )


def test_parse_query_facebook_trumptrain_1461904486():
    verify_serp_parsing(
        "https://web.archive.org/web/20160429043446id_/https://www.facebook.com/search/top/?q=%23TrumpTrain&ref=top_filter&_fb_noscript=1",
        "facebook",
    )


def test_parse_query_facebook_bernieorbust_1467812085():
    verify_serp_parsing(
        "https://web.archive.org/web/20160706133445id_/https://www.facebook.com/search/latest/?q=%23BernieOrBust&ref=top_filter",
        "facebook",
    )


def test_parse_query_facebook_wisconsin_1463064570():
    verify_serp_parsing(
        "https://web.archive.org/web/20160512144930id_/https://www.facebook.com/search/top/?q=wisconsin&_fb_noscript=1",
        "facebook",
    )


def test_parse_query_facebook_alda_lesbiennes_refugiees_1615284371():
    verify_serp_parsing(
        "https://web.archive.org/web/20210309100611id_/https://www.facebook.com/search/top/?q=alda%20-%20lesbiennes%20r%C3%A9fugi%C3%A9es&epa=SEARCH_BOX",
        "facebook",
    )


def test_parse_query_facebook_mens_health_survival_of_the_fittest_1619473718():
    verify_serp_parsing(
        "https://web.archive.org/web/20210426214838id_/http://www.facebook.com/search/?q=mens+health+survival+of+the+fittest&amp;init=quick",
        "facebook",
    )


def test_parse_query_facebook_www_9xcb_biz_webex_setup_was_unsuccessful_error_23_1404412853():
    verify_serp_parsing(
        "https://web.archive.org/web/20140703184053id_/http://www.facebook.com/search.php?q=www.9xcb.biz/?WebEx+Setup+Was+Unsuccessful+Error+23",
        "facebook",
    )


def test_parse_query_facebook_tag_someone_who_needs_this_1587554575():
    verify_serp_parsing(
        "https://web.archive.org/web/20200422112255id_/https://www.facebook.com/search/videos/?q=tag%20someone%20who%20needs%20this&epa=FILTERS&filters=eyJycF9jcmVhdGlvbl90aW1lIjoie1wibmFtZVwiOlwiY3JlYXRpb25fdGltZVwiLFwiYXJnc1wiOlwie1xcXCJzdGFydF95ZWFyXFxcIjpcXFwiMjAyMFxcXCIsXFxcInN0YXJ0X21vbnRoXFxcIjpcXFwiMjAyMC0wNFxcXCIsXFxcImVuZF95ZWFyXFxcIjpcXFwiMjAyMFxcXCIsXFxcImVuZF9tb250aFxcXCI6XFxcIjIwMjAtMDRcXFwiLFxcXCJzdGFydF9kYXlcXFwiOlxcXCIyMDIwLTA0LTIwXFxcIixcXFwiZW5kX2RheVxcXCI6XFxcIjIwMjAtMDQtMjZcXFwifVwifSJ9",
        "facebook",
    )


def test_parse_query_facebook_blog_post_334_bootload_1567494170():
    verify_serp_parsing(
        "https://web.archive.org/web/20190903070250id_/https://developers.facebook.com/search/?q=blog+post+334+bootload&notfound=0&search_filter_option=docs",
        "facebook",
    )


def test_parse_query_facebook_rosy_20gupta_1494524363():
    verify_serp_parsing(
        "https://web.archive.org/web/20170511173923id_/https://www.facebook.com/search/top/?q=rosy%2520gupta",
        "facebook",
    )


def test_parse_query_facebook_social_plugins_boutons_jaime_envoyer_partager_et_citations_js_exec_je31_1567485463():
    verify_serp_parsing(
        "https://web.archive.org/web/20190903043743id_/https://developers.facebook.com/search/?q=social+plugins+boutons+jaime+envoyer+partager+et+citations+js+exec+Je31&notfound=1&search_filter_option=docs",
        "facebook",
    )


def test_parse_query_facebook_greet_1623235952():
    verify_serp_parsing(
        "https://web.archive.org/web/20210609105232id_/http://www.facebook.com/search/?q=Greet&o=2048&init=ffs",
        "facebook",
    )


def test_parse_query_facebook_cruzcrew_1459272010():
    verify_serp_parsing(
        "https://web.archive.org/web/20160329172010id_/https://www.facebook.com/search/photos/?q=%23CruzCrew&ref=top_filter&_fb_noscript=1",
        "facebook",
    )


def test_parse_query_facebook_ineligible_1466870871():
    verify_serp_parsing(
        "https://web.archive.org/web/20160625160751id_/https://www.facebook.com/search/people/?q=%23ineligible&ref=top_filter",
        "facebook",
    )


def test_parse_query_facebook_solcellespecialisten_1389488036():
    verify_serp_parsing(
        "https://web.archive.org/web/20140112005356id_/http://da-dk.facebook.com/search.php?q=Solcellespecialisten&_fb_noscript=1",
        "facebook",
    )


def test_parse_query_facebook_blog_post_319_je31_1567459151():
    verify_serp_parsing(
        "https://web.archive.org/web/20190902211911id_/https://developers.facebook.com/search/?q=blog+post+319+Je31&notfound=1&search_filter_option=news",
        "facebook",
    )



# flake8: noqa
# This file is auto-generated by generate_tests.py.
from archive_query_log.legacy.results.test.test_utils import verify_serp_parsing


def test_parse_query_duckduckgo_3rd_party_twitch_chat_1642095474():
    verify_serp_parsing(
        "https://web.archive.org/web/20220113173754id_/https://duckduckgo.com/?q=3rd+party+twitch+chat&t=brave",
        "duckduckgo",
    )


def test_parse_query_duckduckgo_warren_hunt_1635806147():
    verify_serp_parsing(
        "https://web.archive.org/web/20211101223547id_/https://duckduckgo.com/?t=ffab&q=warren+hunt",
        "duckduckgo",
    )


def test_parse_query_duckduckgo_150_degrees_to_radians_site_degreestoradians_net_1662073498():
    verify_serp_parsing(
        "https://web.archive.org/web/20220901230458id_/https://duckduckgo.com/?q=150%20degrees%20to%20radians+site:degreestoradians.net&t=ffab",
        "duckduckgo",
    )


def test_parse_query_duckduckgo_we_acknowledge_the_traditional_custodians_of_the_land_on_which_our_office_stands_the_wurundjeri_peop_1654920640():
    verify_serp_parsing(
        "https://web.archive.org/web/20220611041040id_/https://duckduckgo.com/?q=We+acknowledge+the+Traditional+Custodians+of+the+land+on+which+our+office+stands%2C+The+Wurundjeri+people+of+the+Kulin+Nation%2C+and+pay+our+respects+to+Elders+past%2C+present+and+emerging.+site%3Awww.sandyps.vic.edu.au&t=opera",
        "duckduckgo",
    )


def test_parse_query_duckduckgo_quit_telnet_site_www_codegrepper_com_1665105234():
    verify_serp_parsing(
        "https://web.archive.org/web/20221007011354id_/https://duckduckgo.com/?q=quit%20telnet+site:www.codegrepper.com&t=ffab&atb=v325-1",
        "duckduckgo",
    )


def test_parse_query_duckduckgo_breaking_news_on_sierra_leone_1663541702():
    verify_serp_parsing(
        "https://web.archive.org/web/20220918225502id_/https://duckduckgo.com/?q=breaking%20news%20on%20sierra%20leone&t=ffab",
        "duckduckgo",
    )


def test_parse_query_duckduckgo_empure_site_empure_in_1664600213():
    verify_serp_parsing(
        "https://web.archive.org/web/20221001045653id_/https://duckduckgo.com/?q=empure+site:empure.in&t=opera",
        "duckduckgo",
    )


def test_parse_query_duckduckgo_elton_john_site_www_esquire_com_1657307467():
    verify_serp_parsing(
        "https://web.archive.org/web/20220708191107id_/https://duckduckgo.com/?q=elton+john+site%3Awww.esquire.com&t=ffcm",
        "duckduckgo",
    )


def test_parse_query_duckduckgo_waterford_house_erfstadt_court_wokingham_berkshire_rg40_2yf_google_maps_1660892879():
    verify_serp_parsing(
        "https://web.archive.org/web/20220819070759id_/https://duckduckgo.com/?q=Waterford+House%2C+Erfstadt+Court+Wokingham%2C+Berkshire%2C+RG40+2YF+google+maps",
        "duckduckgo",
    )


def test_parse_query_duckduckgo_2_5_muiles_to_km_1648676868():
    verify_serp_parsing(
        "https://web.archive.org/web/20220330214748id_/https://duckduckgo.com/?t=ffab&q=2.5+muiles+to+km",
        "duckduckgo",
    )


def test_parse_query_duckduckgo_32168_weather_radar_1667504070():
    verify_serp_parsing(
        "https://web.archive.org/web/20221103193430id_/https://duckduckgo.com/?q=32168%20weather%20radar&t=ffab",
        "duckduckgo",
    )


def test_parse_query_duckduckgo_buck_showalter_seinfeld_1654420295():
    verify_serp_parsing(
        "https://web.archive.org/web/20220605091135id_/https://duckduckgo.com/?q=buck+showalter+seinfeld&t=ffab",
        "duckduckgo",
    )


def test_parse_query_duckduckgo_elite_dangerous_covas_site_www_pcgamer_com_1653704722():
    verify_serp_parsing(
        "https://web.archive.org/web/20220528022522id_/https://duckduckgo.com/?q=elite+dangerous+covas+site%3Awww.pcgamer.com&t=ffab",
        "duckduckgo",
    )


def test_parse_query_duckduckgo_waldo_s_chicken_site_waldoschicken_com_1654372116():
    verify_serp_parsing(
        "https://web.archive.org/web/20220604194836id_/https://duckduckgo.com/?q=waldo%27s+chicken+site%3Awaldoschicken.com&t=ffab",
        "duckduckgo",
    )


def test_parse_query_duckduckgo_sims_castaway_trailer_1647012563():
    verify_serp_parsing(
        "https://web.archive.org/web/20220311152923id_/https://duckduckgo.com/?q=sims+castaway+trailer&t=brave",
        "duckduckgo",
    )


def test_parse_query_duckduckgo_emoji_pedia_site_www_youtube_com_1590838578():
    verify_serp_parsing(
        "https://web.archive.org/web/20200530113618id_/https://duckduckgo.com/?q=emoji%20pedia+site:www.youtube.com&t=ffab",
        "duckduckgo",
    )


def test_parse_query_duckduckgo_sheer_skirt_beach_thing_site_www_lyst_com_1653921398():
    verify_serp_parsing(
        "https://web.archive.org/web/20220530143638id_/https://duckduckgo.com/?q=sheer+skirt+beach+thing+site%3Awww.lyst.com&t=ffab",
        "duckduckgo",
    )


def test_parse_query_duckduckgo_broken_reality_steam_site_www_huntmar_com_1597289631():
    verify_serp_parsing(
        "https://web.archive.org/web/20200813033351id_/https://duckduckgo.com/?q=broken+reality+steam+site%3Awww.huntmar.com&t=ffab",
        "duckduckgo",
    )


def test_parse_query_duckduckgo_sheets_site_www_kohls_com_1642928572():
    verify_serp_parsing(
        "https://web.archive.org/web/20220123090252id_/https://duckduckgo.com/?q=sheets+site%3Awww.kohls.com",
        "duckduckgo",
    )


def test_parse_query_duckduckgo_145_lbs_to_kg_1664351690():
    verify_serp_parsing(
        "https://web.archive.org/web/20220928075450id_/https://duckduckgo.com/?q=145%20lbs%20to%20kg&t=ffab",
        "duckduckgo",
    )


def test_parse_query_duckduckgo_gimp_use_align_tool_site_thegimptutorials_com_1653712700():
    verify_serp_parsing(
        "https://web.archive.org/web/20220528043820id_/https://duckduckgo.com/?q=gimp+use+align+tool+site%3Athegimptutorials.com&t=ffab&atb=v325-7",
        "duckduckgo",
    )


def test_parse_query_duckduckgo_ubuntu_mesa_intel_r_hd_graphics_620_kbl_gt2_site_forum_unity_com_1658976095():
    verify_serp_parsing(
        "https://web.archive.org/web/20220728024135id_/https://duckduckgo.com/?q=ubuntu+Mesa+Intel%28R%29+HD+Graphics+620+%28KBL+GT2%29+site%3Aforum.unity.com&t=ffab",
        "duckduckgo",
    )


def test_parse_query_duckduckgo_2022_07_12_23_00_site_www_time_time_net_1657640396():
    verify_serp_parsing(
        "https://web.archive.org/web/20220712153956id_/https://duckduckgo.com/?q=2022-07-12+23%3A00+site%3Awww.time-time.net&t=ffab",
        "duckduckgo",
    )


def test_parse_query_duckduckgo_branch_conventions_git_site_social_msdn_microsoft_com_1664392383():
    verify_serp_parsing(
        "https://web.archive.org/web/20220928191303id_/https://duckduckgo.com/?q=branch%20conventions%20git+site:social.msdn.microsoft.com&t=ffab",
        "duckduckgo",
    )


def test_parse_query_duckduckgo_enneagram_test_site_www_crystalknows_com_1638683347():
    verify_serp_parsing(
        "https://web.archive.org/web/20211205054907id_/https://duckduckgo.com/?q=enneagram+test+site%3Awww.crystalknows.com",
        "duckduckgo",
    )


def test_parse_query_duckduckgo_universal_logs_checker_1_1_0_site_cracking_org_1656559962():
    verify_serp_parsing(
        "https://web.archive.org/web/20220630033242id_/https://duckduckgo.com/?q=Universal+Logs+Checker+1.1.0+site%3Acracking.org&t=ffcm",
        "duckduckgo",
    )


def test_parse_query_duckduckgo_25_c_to_f_site_www_metric_conversions_org_1655636638():
    verify_serp_parsing(
        "https://web.archive.org/web/20220619110358id_/https://duckduckgo.com/?q=25+C+to+F+site%3Awww.metric-conversions.org&t=ffab",
        "duckduckgo",
    )


def test_parse_query_duckduckgo_u_team_1636548723():
    verify_serp_parsing(
        "https://web.archive.org/web/20211110125203id_/https://duckduckgo.com/?q=u+team",
        "duckduckgo",
    )


def test_parse_query_duckduckgo_sheydim_site_www_sefaria_org_1664233097():
    verify_serp_parsing(
        "https://web.archive.org/web/20220926225817id_/https://duckduckgo.com/?q=Sheydim+site:www.sefaria.org&t=ffcm",
        "duckduckgo",
    )


def test_parse_query_duckduckgo_build_chest_freezer_site_www_quora_com_1654893310():
    verify_serp_parsing(
        "https://web.archive.org/web/20220610203510id_/https://duckduckgo.com/?q=build+chest+freezer+site%3Awww.quora.com&t=ffab",
        "duckduckgo",
    )


def test_parse_query_duckduckgo_jeanne_d_arc_site_id_wikipedia_org_1655183773():
    verify_serp_parsing(
        "https://web.archive.org/web/20220614051613id_/https://duckduckgo.com/?q=Jeanne+d%27Arc+site%3Aid.wikipedia.org&t=ffab&atb=v325-7",
        "duckduckgo",
    )


def test_parse_query_duckduckgo_update_admx_files_on_domain_controller_1660061931():
    verify_serp_parsing(
        "https://web.archive.org/web/20220809161851id_/https://duckduckgo.com/?q=update%20admx%20files%20on%20domain%20controller&t=ffab",
        "duckduckgo",
    )


def test_parse_query_duckduckgo_newest_call_of_duty_game_1653477001():
    verify_serp_parsing(
        "https://web.archive.org/web/20220525111001id_/https://duckduckgo.com/?q=newest+call+of+duty+game&t=ffab&atb=v325-4",
        "duckduckgo",
    )


def test_parse_query_duckduckgo_40_mile_creek_trail_site_www_arizonahighways_com_1657173375():
    verify_serp_parsing(
        "https://web.archive.org/web/20220707055615id_/https://duckduckgo.com/?q=40+mile+creek+trail+site%3Awww.arizonahighways.com&t=ffab",
        "duckduckgo",
    )


def test_parse_query_duckduckgo_united_reformed_churches_in_north_america_1446324275():
    verify_serp_parsing(
        "https://web.archive.org/web/20151031204435id_/https://duckduckgo.com/?q=united+reformed+churches+in+north+america",
        "duckduckgo",
    )


def test_parse_query_duckduckgo_burnout_paradise_online_multiplayer_with_all_dlc_site_www_counton_org_1655566858():
    verify_serp_parsing(
        "https://web.archive.org/web/20220618154058id_/https://duckduckgo.com/?q=burnout+paradise+online+multiplayer+with+all+dlc+site%3Awww.counton.org",
        "duckduckgo",
    )


def test_parse_query_duckduckgo_what_happened_to_greta_thornburg_1667535932():
    verify_serp_parsing(
        "https://web.archive.org/web/20221104042532id_/https://duckduckgo.com/?q=what%20happened%20to%20greta%20thornburg&t=ffab",
        "duckduckgo",
    )


def test_parse_query_duckduckgo_erik_erikson_s_theory_site_positivepsychology_com_1654620203():
    verify_serp_parsing(
        "https://web.archive.org/web/20220607164323id_/https://duckduckgo.com/?q=erik+erikson%27s+theory+site%3Apositivepsychology.com&t=ffab",
        "duckduckgo",
    )


def test_parse_query_duckduckgo_llanelly_carmarthenshire_wales_1655261859():
    verify_serp_parsing(
        "https://web.archive.org/web/20220615025739id_/https://duckduckgo.com/?q=llanelly+carmarthenshire+wales&t=ffab&atb=v325-7",
        "duckduckgo",
    )


def test_parse_query_duckduckgo_c_pretty_print_json_1662310061():
    verify_serp_parsing(
        "https://web.archive.org/web/20220904164741id_/https://duckduckgo.com/?q=c%23%20pretty%20print%20json&t=ffab",
        "duckduckgo",
    )


def test_parse_query_duckduckgo_webassembly_browser_support_list_1653198525():
    verify_serp_parsing(
        "https://web.archive.org/web/20220522054845id_/https://duckduckgo.com/?q=webassembly+browser+support+list&t=ffab",
        "duckduckgo",
    )


def test_parse_query_duckduckgo_bulk_copper_pennies_for_sale_1646606334():
    verify_serp_parsing(
        "https://web.archive.org/web/20220306223854id_/https://duckduckgo.com/?q=bulk+copper+pennies+for+sale&t=opera",
        "duckduckgo",
    )


def test_parse_query_duckduckgo_ubuntu_netplan_package_site_www_ubuntuupdates_org_1665115336():
    verify_serp_parsing(
        "https://web.archive.org/web/20221007040216id_/https://duckduckgo.com/?q=ubuntu%20netplan%20package+site:www.ubuntuupdates.org&t=ffab",
        "duckduckgo",
    )


def test_parse_query_duckduckgo_ukraine_site_www_cfr_org_1646796603():
    verify_serp_parsing(
        "https://web.archive.org/web/20220309033003id_/https://duckduckgo.com/?q=Ukraine+site%3Awww.cfr.org&t=opera",
        "duckduckgo",
    )


def test_parse_query_duckduckgo_simplify_subtraction_of_fractals_site_www_thecalculator_co_1637459222():
    verify_serp_parsing(
        "https://web.archive.org/web/20211121014702id_/https://duckduckgo.com/?q=simplify+subtraction+of+fractals+site%3Awww.thecalculator.co&t=brave",
        "duckduckgo",
    )


def test_parse_query_duckduckgo_equation_of_dissociation_of_sulfuric_acid_site_www_sciencedirect_com_1649296927():
    verify_serp_parsing(
        "https://web.archive.org/web/20220407020207id_/https://duckduckgo.com/?q=equation+of+dissociation+of+sulfuric+acid+site%3Awww.sciencedirect.com&t=ffab",
        "duckduckgo",
    )


def test_parse_query_duckduckgo_elite_dangerous_site_www_thegamer_com_1658908937():
    verify_serp_parsing(
        "https://web.archive.org/web/20220727080217id_/https://duckduckgo.com/?q=Elite%3A+Dangerous+site%3Awww.thegamer.com&t=ffab",
        "duckduckgo",
    )


def test_parse_query_duckduckgo_website_sitemap_finder_site_seositecheckup_com_1614287233():
    verify_serp_parsing(
        "https://web.archive.org/web/20210225210713id_/https://duckduckgo.com/?q=website+sitemap+finder+site%3Aseositecheckup.com&t=brave",
        "duckduckgo",
    )


def test_parse_query_duckduckgo_encountered_conflicts_when_cherry_picking_commit_1618189582():
    verify_serp_parsing(
        "https://web.archive.org/web/20210412010622id_/https://duckduckgo.com/?q=encountered+conflicts+when+cherry+picking+commit&t=ffab",
        "duckduckgo",
    )



from click import group, option

from archive_query_log.cli.util import pass_config
from archive_query_log.config import Config
from archive_query_log.orm import Source


@group()
def sources():
    pass


@sources.command()
@option("--skip-archives", is_flag=True)
@option("--skip-providers", is_flag=True)
@pass_config
def build(
        config: Config,
        skip_archives: bool,
        skip_providers: bool,
) -> None:
    from archive_query_log.sources import build_sources
    Source.init(using=config.es.client, index=config.es.index_sources)
    build_sources(
        config=config,
        skip_archives=skip_archives,
        skip_providers=skip_providers,
    )
